==> nextcloud-app-news-1:25.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/fi.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, yhteys ei ole käytettävissä!",
    "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
    "Request forbidden. Are you an administrator?" : "Pyyntö ei ole valtuutettu. Oletko ylläpitäjä?",
    "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
    "News feeds" : "Syötteet",
    "Unread articles" : "Lukemattomat artikkelit",
    "News" : "Uutiset",
    "News folders" : "Syötekansiot",
    "News articles" : "Uutisartikkelit",
    "Shared with me" : "Jaettu kanssasi",
    "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
    "Download" : "Lataa",
    "Close" : "Sulje",
    "Web address" : "Verkko-osoite",
    "No folder" : "Ei kansiota",
    "Folder name" : "Kansion nimi",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Feed exists already!" : "Syöte on jo olemassa!",
    "New folder" : "Uusi kansio",
    "Folder exists already!" : "Kansio on jo olemassa!",
    "Credentials" : "Tilitiedot",
    "Auto discover Feed" : "Löydä syöte automaattisesti",
    "Subscribe" : "Tilaa",
    "Last job ran {relativeTime}." : "Viimeisin työ ajettiin {relativeTime}.",
    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
    "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
    "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
    "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
    "Update interval" : "Päivitysväli",
    "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
    "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
    "Delete unread articles automatically" : "Poista lukemattomat artikkelit automaattisesti",
    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
    "No article selected" : "Artikkelia ei ole valittu",
    "Please select an article from the list..." : "Valitse artikkeli listalta...",
    "Move" : "Siirrä",
    "User Name" : "Käyttäjänimi",
    "Share" : "Jaa",
    "Share with" : "Jaa",
    "Share with {num} users" : "Jaa {num} käyttäjän kanssa",
    "Mark read" : "Merkitse luetuksi",
    "All articles" : "Kaikki artikkelit",
    "Starred" : "Suosikit",
    "Explore" : "Löydä uusia",
    "Settings" : "Asetukset",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Disable mark read through scrolling" : "Älä merkitse luetuksi vierittäessä",
    "Compact view" : "Tiivis näkymä",
    "Show all articles" : "Näytä kaikki artikkelit",
    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ensin)",
    "Rename Folder" : "Nimeä kansio uudelleen",
    "Are you sure you want to delete?" : "Haluatko varmasti poistaa?",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Open Feed URL" : "Avaa syötteen osoite",
    "Rename Feed" : "Nimeä syöte uudelleen",
    "Unpin from top" : "Poista kiinnitys ylhäältä",
    "Pin to top" : "Kiinnitä ylös",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Default order" : "Oletusjärjestys",
    "Enable full text" : "Lataa koko teksti",
    "Disable full text" : "Älä lataa koko tekstiä",
    "Toggle star article" : "Suosikkimerkintä päälle/pois",
    "Mark unread" : "Merkitse lukemattomaksi",
    "Close details" : "Sulje tiedot",
    "by" : "Kirjoittaja:",
    "from" : "Syöte:",
    "shared by" : "jakanut",
    "Play audio" : "Toista äänet",
    "Download audio" : "Lataa äänet",
    "Download video" : "Lataa video",
    "Open website" : "Avaa verkkosivu",
    "Keep article unread" : "Pidä artikkeli lukemattomana",
    "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
    "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
    "{num} seconds" : "{num} sekuntia",
    "{num} minutes ago" : "{num} minuuttia sitten",
    "{num} hours ago" : "{num} tuntia sitten",
    "{num} days ago" : "{num} päivää sitten",
    "{num} months ago" : "{num} kuukautta sitten",
    "{num} years ago" : "{num} vuotta sitten",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Action" : "Toiminto",
    "right" : "oikea",
    "Jump to next article" : "Siirry seuraavaan artikkeliin",
    "left" : "vasen",
    "Jump to previous article" : "Siirry edelliseen artikkeliin",
    "Star article and jump to next one" : "Lisää artikkeli suosikkeihin ja siirry seuraavaan",
    "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
    "Refresh" : "Päivitä",
    "Load next feed" : "Lataa seuraava syöte",
    "Load previous feed" : "Lataa edellinen syöte",
    "Load previous folder" : "Lataa edellinen kansio",
    "Load next folder" : "Lataa seuraava kansio",
    "Scroll to active navigation entry" : "Vieritä syötelista aktiivisen syötteen kohdalle",
    "Shift" : "Siirrä",
    "All Articles" : "Kaikki artikkelit",
    "Subscribe to" : "Tilaa",
    "Unread Articles" : "Lukemattomat artikkelit",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
    "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a",
    "No articles available" : "Artikkeleita ei ole saatavilla",
    "No unread articles available" : "Lukemattomia artikkeleita ei ole saatavilla",
    "Star article" : "Lisää artikkeli suosikkeihin",
    "Unstar article" : "Poista artikkeli suosikeista",
    "Share with users" : "Jaa käyttäjien kanssa",
    "No users found" : "Käyttäjiä ei löytynyt",
    "Error while searching for users" : "Virhe käyttäjien etsinnässä",
    "Share on social media" : "Jaa sosiaalisessa mediassa",
    "I wanted you to see this article" : "Halusin sinun näkevän tämän artikkelin",
    "Check out this article" : "Katso tämä artikkeli",
    "Description" : "Kuvaus",
    "Toggle expand article in compact view" : "Laajenna artikkeli tiivissä näkymässä/supista artikkeli",
    "Mark current article's feed/folder read" : "Merkitse nykyisen artikkelin syöte/kansio luetuksi",
    "Folder" : "Kansio",
    "Go back" : "Takaisin",
    "New Folder" : "Uusi kansio",
    "Create" : "Luo",
    "Update failed more than 50 times" : "Päivitys epäonnistui yli 50 kertaa",
    "Deleted feed" : "Syöte poistettu",
    "Undo delete feed" : "Kumoa syötteen poistaminen",
    "Menu" : "Valikko",
    "Open feed URL" : "Avaa syötteen osoite",
    "Dismiss" : "Hylkää",
    "Collapse" : "Kutista näkymää",
    "Deleted folder" : "Kansio poistettu",
    "Undo delete folder" : "Kumoa kansion poistaminen",
    "Expand articles on key navigation" : "Laajenna artikkelit näppäimistöllä navigoidessa",
    "Subscriptions (OPML)" : "Tilaukset (OPML)",
    "Import" : "Tuo",
    "Export" : "Vie",
    "Error when importing: File does not contain valid OPML" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista OPML:ää",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Virhe tuotaessa: OPML ei sisällä syötteitä tai kansioita",
    "Unread/Starred Articles" : "Suosikit ja lukemattomat artikkelit",
    "Error when importing: file does not contain valid JSON" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista JSONia",
    "Help" : "Ohje",
    "Documentation" : "Dokumentaatio",
    "Report a bug" : "Ilmoita viasta"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1:26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/fi.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Syötteet",
    "Unread articles" : "Lukemattomat artikkelit",
    "News" : "Uutiset",
    "News folders" : "Syötekansiot",
    "News articles" : "Uutisartikkelit",
    "Shared with me" : "Jaettu kanssasi",
    "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
    "Download" : "Lataa",
    "Close" : "Sulje",
    "Web address" : "Verkko-osoite",
    "No folder" : "Ei kansiota",
    "Folder name" : "Kansion nimi",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Feed exists already!" : "Syöte on jo olemassa!",
    "New folder" : "Uusi kansio",
    "Folder exists already!" : "Kansio on jo olemassa!",
    "Credentials" : "Tilitiedot",
    "Auto discover Feed" : "Löydä syöte automaattisesti",
    "Subscribe" : "Tilaa",
    "Last job ran {relativeTime}." : "Viimeisin työ ajettiin {relativeTime}.",
    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
    "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
    "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
    "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
    "Update interval" : "Päivitysväli",
    "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
    "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
    "Delete unread articles automatically" : "Poista lukemattomat artikkelit automaattisesti",
    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
    "No article selected" : "Artikkelia ei ole valittu",
    "Please select an article from the list..." : "Valitse artikkeli listalta...",
    "Move" : "Siirrä",
    "User Name" : "Käyttäjänimi",
    "Share" : "Jaa",
    "Share with" : "Jaa",
    "Share with {num} users" : "Jaa {num} käyttäjän kanssa",
    "Default" : "Oletus",
    "Vertical" : "Pystysuora",
    "Horizontal" : "Vaakasuora",
    "Rename Folder" : "Nimeä kansio uudelleen",
    "Are you sure you want to delete?" : "Haluatko varmasti poistaa?",
    "Mark read" : "Merkitse luetuksi",
    "All articles" : "Kaikki artikkelit",
    "Starred" : "Suosikit",
    "Explore" : "Löydä uusia",
    "Settings" : "Asetukset",
    "Documentation" : "Dokumentaatio",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Disable mark read through scrolling" : "Älä merkitse luetuksi vierittäessä",
    "Show all articles" : "Näytä kaikki artikkelit",
    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ensin)",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Rename Feed" : "Nimeä syöte uudelleen",
    "Open Feed URL" : "Avaa syötteen osoite",
    "Unpin from top" : "Poista kiinnitys ylhäältä",
    "Pin to top" : "Kiinnitä ylös",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Default order" : "Oletusjärjestys",
    "Enable full text" : "Lataa koko teksti",
    "Disable full text" : "Älä lataa koko tekstiä",
    "Previous" : "Edellinen",
    "Next" : "Seuraava",
    "Toggle star article" : "Suosikkimerkintä päälle/pois",
    "Mark unread" : "Merkitse lukemattomaksi",
    "Close details" : "Sulje tiedot",
    "shared by" : "jakanut",
    "by" : "Kirjoittaja:",
    "Play audio" : "Toista äänet",
    "Download audio" : "Lataa äänet",
    "Download video" : "Lataa video",
    "Open website" : "Avaa verkkosivu",
    "Keep article unread" : "Pidä artikkeli lukemattomana",
    "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
    "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
    "Please wait" : "Odota hetki",
    "Title" : "Nimeke",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Action" : "Toiminto",
    "Jump to next article" : "Siirry seuraavaan artikkeliin",
    "Jump to previous article" : "Siirry edelliseen artikkeliin",
    "right" : "oikea",
    "left" : "vasen",
    "Star article and jump to next one" : "Lisää artikkeli suosikkeihin ja siirry seuraavaan",
    "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
    "Refresh" : "Päivitä",
    "Load next feed" : "Lataa seuraava syöte",
    "Load previous feed" : "Lataa edellinen syöte",
    "Load previous folder" : "Lataa edellinen kansio",
    "Load next folder" : "Lataa seuraava kansio",
    "Scroll to active navigation entry" : "Vieritä syötelista aktiivisen syötteen kohdalle",
    "Shift" : "Siirrä",
    "All Articles" : "Kaikki artikkelit",
    "Subscribe to" : "Tilaa",
    "Unread Articles" : "Lukemattomat artikkelit",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
    "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a"
},
"nplurals=2; plural=(n != 1);");
